# NQRduck Module: $MODULE_NAME

This module  is a template for the creation of new modules. It provides a basic structure for the creation of new modules.
This Readme file should be used as a template for the README.md file of new modules.
Add a short description of the module here but describe the usage in the Usage section.

## Installation

### Requirements
Describe the requirements for the module. Usually dependencies are handled via the pyproject.toml file but if the user needs to install additional software or libraries, it should be mentioned here. Also mention that the user needs to install the NQRduck core.

### Setup
Describe how to install the module. Usually the user needs to install the NQRduck core first. Then the user can install the module by running the following command in the terminal:
```bash
pip install .
```

## Usage
Describe how to use the module. This should include a short description of the module and how it is used together with the NQRduck core.
If it's an UI module ideally include a screenshot of the UI.

### Notes
Add additional notes here. This could be information about the usage of the module or additional information about the module.

## License
Usually the modules are licensed under the MIT License. The license file should be included in the module. The license file should be named LICENSE and should be in the root directory of the module.

## Contributing
If you're interested in contributing to the project, start by checking out our [nqrduck-module template](https://github.com/nqrduck/nqrduck-module). To contribute to existing modules, please first open an issue in the respective module repository to discuss your ideas or report bugs.
```